@@ -1364,7 +1364,7 @@ gf_qqstep <-
 #' Formula interace to empirical cumulative distribution
 #'
 #' The empirical cumulative distribution function (ECDF) provides an alternative
-#' visualisation of distribution. Compared to other visualisations that rely on
+#' visualization of distribution. Compared to other visualizations that rely on
 #' density (like histograms or density plots) the ECDF doesn't require any tuning
 #' parameters and handles both continuous and categorical variables. The
 #' downside is that it requires more training to accurately interpret, and the
@@ -2199,6 +2199,26 @@ gf_fitdistr <-
     note = "dist should be a density function like dnorm or dgamma"
   )
 
+#' Formula interface to geom_sina()
+#'
+#' @inherit ggforce::geom_sina description references
+#' @inherit gf_line
+#' @inheritParams ggforce::geom_sina
+#' @inheritParams ggforce::stat_sina
+#'
+#' @seealso [ggforce::geom_sina()]
+#' @examples
+#' gf_sina(age ~ substance, data = mosaicData::HELPrct)
+#'
+#' @export
+
+gf_sina <-
+  layer_factory(
+    geom = "point", stat = "sina", position = "identity",
+    extras = alist(alpha = , color = , size = , fill = , group = )
+  )
+
+
 #' Mapping with shape files
 #'
 #' Mapping with shape files
@@ -2282,4 +2302,3 @@ gf_empty <- function(environment = parent.frame()) {
   ggplot2::ggplot(environment = environment)
 }
 
-
